@@ -5,11 +5,11 @@
 #
 # For more advanced comment options see comments2.py.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('comments1.xlsx')
+workbook = xlsxwriter.Workbook('comments1.xlsx')
 worksheet = workbook.add_worksheet()
 
 worksheet.write('A1', 'Hello')
