@@ -4,11 +4,11 @@
 # default worksheet direction from left-to-right to right-to-left as
 # required by some middle eastern versions of Excel.
 #
-# Copyright 2013, John McNamara, jmcnamara@cpan.org
+# Copyright 2013-2014, John McNamara, jmcnamara@cpan.org
 #
-from xlsxwriter.workbook import Workbook
+import xlsxwriter
 
-workbook = Workbook('right_to_left.xlsx')
+workbook = xlsxwriter.Workbook('right_to_left.xlsx')
 
 # Add two worksheets.
 worksheet1 = workbook.add_worksheet()
